Changelog
=========


1.0.0b4 (2023-11-06)
--------------------

- Fix street search to include disable street
  [jchandelle]


1.0.0b3 (2023-09-19)
--------------------

- Add imio.restapi dependency
  [jchandelle]

- Adapt street retrieval key [SUP-31682]
  [jchandelle]


1.0.0b2 (2023-07-24)
--------------------

- Fix multiresult in street search with exact match [URB-2696]
  [jchandelle]


1.0.0b1 (2023-06-29)
--------------------

- Fix POST endpoint for event creation [URB-2730]
  [jchandelle]

- Add utils for getting config object from a path
  [jchandelle]

- Fix address query with parenthesis [URB-2696]
  [jchandelle]


1.0a1 (2023-04-05)
------------------

- Initial release.
  [jjaumotte]
